==> billogram-foundation-3.13.10.tgz: package/modules/components/dropdown/option-link/DropdownLinkOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';


export default ({
    block,
    displayName
} = {}) => {

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            highlighted: PropTypes.bool,
            showArrow: PropTypes.bool,
            text: PropTypes.string,
            to: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                highlighted: false,
                showArrow: true,
                text: '',
                to: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        renderArrow() {
            if (!this.props.showArrow) {
                return null;
            }

            return (
                <i className={ block('option-arrow') } />
            );
        },

        render() {
            const { disabled, highlighted, text, to } = this.props;
            return (
                <a
                    className={ block('option', { disabled, highlighted }, ['arrow']) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    title={ text }>
                    { text }
                    { this.renderArrow() }
                </a>
            );
        }

    });

};

==> billogram-foundation-4.4.0.tgz: package/modules/components/dropdown/option-link/DropdownLinkOption.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';


export default ({
    block,
    displayName
} = {}) => {

    return React.createClass({

        displayName,

        mixins: [PureRenderMixin],

        propTypes: {
            disabled: PropTypes.bool,
            highlighted: PropTypes.bool,
            showArrow: PropTypes.bool,
            text: PropTypes.node,
            to: PropTypes.string
        },

        getDefaultProps() {
            return {
                disabled: false,
                highlighted: false,
                showArrow: true,
                text: '',
                to: ''
            };
        },

        onClick(evt) {
            if (this.props.disabled) {
                evt.preventDefault();
            }
        },

        renderArrow() {
            if (!this.props.showArrow) {
                return null;
            }

            return (
                <i className={ block('option-arrow') } />
            );
        },

        render() {
            const { disabled, highlighted, text, to } = this.props;
            return (
                <a
                    className={ block('option', { disabled, highlighted }, ['arrow']) }
                    data-load="static"
                    href={ to }
                    onClick={ this.onClick }
                    title={ text }>
                    { text }
                    { this.renderArrow() }
                </a>
            );
        }

    });

};
